//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d11 $

//================================================================================
#ifndef DATACMDPRT_H
#include "DataCmdPrt.h"		// CDataCmdPart
#endif

#ifndef _DATACMDFRAME_
#include "DataCmdFrm.h"		// CDataCmdFrame
#endif

#ifndef PIZZA_H
#include "Pizza.h"			//  CPizza
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWMEMMGR_H
#include "FWMemMgr.h"		// FW_CMemoryManager
#endif

//==============================================================================
const ODValueType CDataCmdPart::kPartKind = kDataCmdKind;
const ODValueType CDataCmdPart::kPartUserName = kDataCmdEditorUserString;

#define kMainPresentation	"Apple:Presentation:DataCmd"

#ifdef FW_BUILD_MAC
#pragma segment DataCmd
#endif

//==============================================================================
CDataCmdPart::CDataCmdPart(ODPart* odPart)
  :	FW_CPart(odPart, kPartKind, kPartUserName, FW_gInstance, kPartIconID),
	fNumPizzas(0),
	fStringPtr(NULL),
	fBufferPtr(NULL),
	fBufferBytes(0),
	fPresentation(NULL),
	fPizzaList(NULL)
{
}

//--------------------------------------------------------------------------------
CDataCmdPart::~CDataCmdPart()
{
	delete fStringPtr;
	FW_CMemoryManager::FreeBlock(fBufferPtr);
	CPizza* pizza = NULL;
	while ((pizza = (CPizza*)fPizzaList->First()) != NULL) {
		fPizzaList->Remove(pizza);
		delete pizza;
		}
	delete fPizzaList;
}

//--------------------------------------------------------------------------------
void 
CDataCmdPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	fPresentation = this->RegisterPresentation(ev, kMainPresentation, TRUE, NULL);
	// init strings
	fEmbeddedString.ReplaceAll("Embedded string");
	fStringPtr = FW_NEW(FW_CString32, ("String Pointer") );

	// init buffer
	fBufferBytes = 1000;
	fBufferPtr = FW_CMemoryManager::AllocateBlock(fBufferBytes);	

	fPizzaList = new FW_CPrivOrderedCollection;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CDataCmdPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(presentation);
	FW_UNUSED(fromStorage);
	return new CDataCmdFrame(ev, odFrame, presentation, this);
}

//--------------------------------------------------------------------------------
void 
CDataCmdPart::MyInvalidatePresentation(Environment* ev, FW_CRect& invalidRect)
{
	fPresentation->Invalidate(ev, invalidRect);
}

//--------------------------------------------------------------------------------
void 
CDataCmdPart::MyIncrement(Environment* ev, FW_CPoint position)
{
	fNumPizzas++;
	FW_CRect bounds(FW_IntToFixed(0), FW_IntToFixed(0), FW_IntToFixed(30), FW_IntToFixed(30));
	bounds.Offset(position);
	CPizza* pizza = new CPizza(bounds);
	fPizzaList->AddLast(pizza);
	this->MyInvalidatePresentation(ev, bounds);	
}

//--------------------------------------------------------------------------------
void 
CDataCmdPart::MyDecrement(Environment* ev)
{
	fNumPizzas--;
	CPizza* pizza = (CPizza*)fPizzaList->RemoveLast();
	this->MyInvalidatePresentation(ev, pizza->GetBounds());	
}

//--------------------------------------------------------------------------------
FW_CPrivOrderedCollection* 
CDataCmdPart::MyGetPizzaList()
{
	return fPizzaList;
}
